@@ -1,18 +1,26 @@
 #implements order MCMC on an extended search space, MAP version
-orderMCMCplus1max<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,parenttable,scoretable,aliases,numparents,
-                         rowmaps,plus1lists,maxmatrices,numberofparentsvec,gamma=1,bgnodes,bglogscore) {
+orderMCMCplus1max<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,
+                            parenttable,scoretable,aliases,numparents,
+                         rowmaps,plus1lists,maxmatrices,numberofparentsvec,
+                         gamma=1,bgnodes,matsize) {
   
-  if(nsmall<n) {
-    mainnodes<-c(1:n)[-bgnodes]
-  } else {mainnodes<-c(1:n)}
+  #n - number of nodes (background included)
+  #nsmall - number of nodes excluding background
+  #matsize - number of rows/columns in adjacency matrix 
+  
+ # prevmove<-2
+  
+  if(!is.null(bgnodes)) {
+    mainnodes<-c(1:matsize)[-bgnodes]
+  } else {mainnodes<-c(1:matsize)}
   
   currentpermy<-startorder #starting order represented as a permutation
-  currentorderscores<-orderscorePlus1max(n,startorder[1:nsmall],c(1:nsmall),parenttable,
-                                         aliases,numparents,plus1lists,rowmaps,scoretable,
+  currentorderscores<-orderscorePlus1max(matsize,scorenodes=startorder[1:nsmall],scorepositions=c(1:nsmall),
+                                         parenttable,aliases,numparents,plus1lists,rowmaps,scoretable,
                                          maxmatrices,currentpermy) #starting score
-  currenttotallogscore<-sum(currentorderscores$totscores[mainnodes],bglogscore) #log total score of all DAGs in the starting order
-  currentDAG<-samplescoreplus1.max(n,mainnodes,currentorderscores,plus1lists,maxmatrices,scoretable,
-                                   parenttable,numberofparentsvec,aliases,bglogscore=bglogscore) #score of a single DAG sampled from the starting order
+  currenttotallogscore<-sum(currentorderscores$totscores[mainnodes]) #log score of a maximum DAG in the starting order
+  currentDAG<-samplescoreplus1.max(matsize,mainnodes,currentorderscores,plus1lists,maxmatrices,scoretable,
+                                   parenttable,numberofparentsvec,aliases) #score of a single DAG sampled from the starting order
   L1 <- list() # stores the adjacency matrix of a DAG sampled from the orders
   L2 <- list() # stores its log BGe score
   L3 <- list() # stores the log BGe score of the entire order
@@ -27,7 +35,7 @@ orderMCMCplus1max<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,pa
   L1[[1]]<-currentDAG$incidence #starting DAG adjacency matrix
   L2[[1]]<-currentDAG$logscore #starting DAG score
   L3[[1]]<-currenttotallogscore #starting order score
-  L4[[1]]<-currentpermy #starting order
+  L4[[1]]<-currentpermy[1:nsmall] #starting order
 
   moveprobsstart<-moveprobs
 
@@ -60,9 +68,10 @@ orderMCMCplus1max<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,pa
         if (chosenmove < 3) {
           scorepositions<-c(min(sampledelements):max(sampledelements))
           proposedpermy[sampledelements]<-currentpermy[rev(sampledelements)] #proposed new order ???
-          rescorenodes<-proposedpermy[scorepositions] #we only need to rescore these nodes between the swapped elements to speed up the calculation
-          proposedorderrescored<-orderscorePlus1max(n,rescorenodes,scorepositions,parenttable,aliases,numparents,plus1lists,rowmaps,scoretable,maxmatrices,proposedpermy)
-          proposedtotallogscore<-currenttotallogscore-sum(currentorderscores$totscores[rescorenodes])+sum(proposedorderrescored$totscores[rescorenodes]) #and the new log total score by updating only the necessary nodes
+           rescorenodes<-proposedpermy[scorepositions] #we only need to rescore these nodes between the swapped elements to speed up the calculation
+           proposedorderrescored<-orderscorePlus1max(matsize,rescorenodes,scorepositions,parenttable,aliases,numparents,plus1lists,rowmaps,scoretable,maxmatrices,proposedpermy)
+           proposedtotallogscore<-currenttotallogscore-sum(currentorderscores$totscores[rescorenodes])+sum(proposedorderrescored$totscores[rescorenodes]) #and the new log total score by updating only the necessary nodes
+          
           scoreratio<-exp((proposedtotallogscore-currenttotallogscore)*gamma) #acceptance probability
 
           if(runif(1)<scoreratio){ #Move accepted then set the current order and scores to the proposal
@@ -77,7 +86,7 @@ orderMCMCplus1max<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,pa
 
           } else if (chosenmove==3) {
 
-            neworder<-positionscorePlus1max(n,nsmall,currentorderscores,sampledpos,currentpermy,aliases,
+            neworder<-positionscorePlus1max(matsize,nsmall,currentorderscores,sampledpos,currentpermy,aliases,
                                             rowmaps,plus1lists,numparents,scoretable,maxmatrices)
             currentorderscores<-neworder$score
             currentpermy<-neworder$order
@@ -85,13 +94,13 @@ orderMCMCplus1max<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,pa
           }
       }
     }
-
-    currentDAG<-samplescoreplus1.max(n,mainnodes,currentorderscores,plus1lists,maxmatrices,scoretable,
-                                     parenttable,numberofparentsvec,aliases,bglogscore=bglogscore)
+    
+    currentDAG<-samplescoreplus1.max(matsize,mainnodes,currentorderscores,plus1lists,maxmatrices,scoretable,
+                                     parenttable,numberofparentsvec,aliases)
     L1[[z]]<-currentDAG$incidence #store adjacency matrix of a sampled DAG each 'stepsave'
     L2[[z]]<-currentDAG$logscore #and log score of a sampled DAG
     L3[[z]]<-currenttotallogscore #and the current order score
-    L4[[z]]<-currentpermy #and store current order
+    L4[[z]]<-currentpermy[1:nsmall] #and store current order
   }
   result<-list()
   result$incidence<-L1
